==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/LaunchApplicationActionType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LaunchApplicationActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LaunchApplicationActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="applicationPath" type="{http://schema.webpdf.de/1.0/operation}FileSpecificationType" minOccurs="0"/&gt;
 *         &lt;element name="launchParameters" type="{http://schema.webpdf.de/1.0/operation}LaunchParameterType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="newWindow" type="{http://schema.webpdf.de/1.0/operation}OpenModeType" default="userPreferences" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LaunchApplicationActionType", propOrder = {
    "applicationPath",
    "launchParameters"
})
public class LaunchApplicationActionType
    extends ActionEventType
{

    protected FileSpecificationType applicationPath;
    protected LaunchParameterType launchParameters;
    @XmlAttribute(name = "newWindow")
    protected OpenModeType newWindow;

    /**
     * Gets the value of the applicationPath property.
     * 
     * @return
     *     possible object is
     *     {@link FileSpecificationType }
     *     
     */
    public FileSpecificationType getApplicationPath() {
        return applicationPath;
    }

    /**
     * Sets the value of the applicationPath property.
     * 
     * @param value
     *     allowed object is
     *     {@link FileSpecificationType }
     *     
     */
    public void setApplicationPath(FileSpecificationType value) {
        this.applicationPath = value;
    }

    public boolean isSetApplicationPath() {
        return (this.applicationPath!= null);
    }

    /**
     * Gets the value of the launchParameters property.
     * 
     * @return
     *     possible object is
     *     {@link LaunchParameterType }
     *     
     */
    public LaunchParameterType getLaunchParameters() {
        return launchParameters;
    }

    /**
     * Sets the value of the launchParameters property.
     * 
     * @param value
     *     allowed object is
     *     {@link LaunchParameterType }
     *     
     */
    public void setLaunchParameters(LaunchParameterType value) {
        this.launchParameters = value;
    }

    public boolean isSetLaunchParameters() {
        return (this.launchParameters!= null);
    }

    /**
     * Gets the value of the newWindow property.
     * 
     * @return
     *     possible object is
     *     {@link OpenModeType }
     *     
     */
    public OpenModeType getNewWindow() {
        if (newWindow == null) {
            return OpenModeType.USER_PREFERENCES;
        } else {
            return newWindow;
        }
    }

    /**
     * Sets the value of the newWindow property.
     * 
     * @param value
     *     allowed object is
     *     {@link OpenModeType }
     *     
     */
    public void setNewWindow(OpenModeType value) {
        this.newWindow = value;
    }

    public boolean isSetNewWindow() {
        return (this.newWindow!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/LaunchApplicationActionType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The launchApplication element will open another application or document when activated. The "applicationPath" subelement is required. "launchParameters" is optional.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for LaunchApplicationActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="LaunchApplicationActionType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType">
 *       <all>
 *         <element name="applicationPath" type="{http://schema.webpdf.de/1.0/operation}FileSpecificationType" minOccurs="0"/>
 *         <element name="launchParameters" type="{http://schema.webpdf.de/1.0/operation}LaunchParameterType" minOccurs="0"/>
 *       </all>
 *       <attribute name="newWindow" type="{http://schema.webpdf.de/1.0/operation}OpenModeType" default="userPreferences" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LaunchApplicationActionType", propOrder = {
    "applicationPath",
    "launchParameters"
})
public class LaunchApplicationActionType
    extends ActionEventType
{

    protected FileSpecificationType applicationPath;
    protected LaunchParameterType launchParameters;
    @XmlAttribute(name = "newWindow")
    protected OpenModeType newWindow;

    /**
     * Gets the value of the applicationPath property.
     * 
     * @return
     *     possible object is
     *     {@link FileSpecificationType }
     *     
     */
    public FileSpecificationType getApplicationPath() {
        return applicationPath;
    }

    /**
     * Sets the value of the applicationPath property.
     * 
     * @param value
     *     allowed object is
     *     {@link FileSpecificationType }
     *     
     */
    public void setApplicationPath(FileSpecificationType value) {
        this.applicationPath = value;
    }

    public boolean isSetApplicationPath() {
        return (this.applicationPath!= null);
    }

    /**
     * Gets the value of the launchParameters property.
     * 
     * @return
     *     possible object is
     *     {@link LaunchParameterType }
     *     
     */
    public LaunchParameterType getLaunchParameters() {
        return launchParameters;
    }

    /**
     * Sets the value of the launchParameters property.
     * 
     * @param value
     *     allowed object is
     *     {@link LaunchParameterType }
     *     
     */
    public void setLaunchParameters(LaunchParameterType value) {
        this.launchParameters = value;
    }

    public boolean isSetLaunchParameters() {
        return (this.launchParameters!= null);
    }

    /**
     * Gets the value of the newWindow property.
     * 
     * @return
     *     possible object is
     *     {@link OpenModeType }
     *     
     */
    public OpenModeType getNewWindow() {
        if (newWindow == null) {
            return OpenModeType.USER_PREFERENCES;
        } else {
            return newWindow;
        }
    }

    /**
     * Sets the value of the newWindow property.
     * 
     * @param value
     *     allowed object is
     *     {@link OpenModeType }
     *     
     */
    public void setNewWindow(OpenModeType value) {
        this.newWindow = value;
    }

    public boolean isSetNewWindow() {
        return (this.newWindow!= null);
    }

}
